#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pcre-light
version:              0.4.1.0
visibility:           public
id:                   pcre-light-0.4.1.0-H2hxeQpSItnJ59X9TljXv
key:                  pcre-light-0.4.1.0-H2hxeQpSItnJ59X9TljXv
license:              BSD-3-Clause
copyright:            (c) 2007-2010. Don Stewart <dons@galois.com>
maintainer:           Daniel Díaz <dhelta.diaz@gmail.com>
author:               Don Stewart
homepage:             https://github.com/Daniel-Diaz/pcre-light
synopsis:
    Portable regex library for Perl 5 compatible regular expressions

description:
    A small, efficient and portable regex library for Perl 5 compatible regular expressions

    The PCRE library is a set of functions that implement regular
    expression pattern matching using the same syntax and semantics as Perl 5.

    If installation fails reporting that you are missing the prce C library, try installing
    the @libpcre3-dev@ package (linux) or @brew install pcre@ (MacOS).

category:             Text
abi:                  9449907cb8ec68fbda8ee9f742441215
exposed:              True
exposed-modules:
    Text.Regex.PCRE.Light Text.Regex.PCRE.Light.Base
    Text.Regex.PCRE.Light.Char8

import-dirs:          /usr/lib/ghc-8.10.5/site-local/pcre-light-0.4.1.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/pcre-light-0.4.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/pcre-light-0.4.1.0
hs-libraries:         HSpcre-light-0.4.1.0-H2hxeQpSItnJ59X9TljXv
extra-libraries:      pcre
depends:              base-4.14.2.0 bytestring-0.10.12.0
haddock-interfaces:   /usr/share/doc/haskell-pcre-light/html/pcre-light.haddock
haddock-html:         /usr/share/doc/haskell-pcre-light/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

